@@ -147,4 +147,4 @@ from ._component import PropsDict, Component, make_component, register_props, Re
 from .state import StateValue, StateManager
 from .app import App
 from .base_components import *
-from .utilities import alert, Timer, set_trace
+from .utilities import alert, file_dialog, Timer, set_trace
